pub enum ObjectByteRange {
Bounded {
start: u64,
end_exclusive: u64,
},
From {
start: u64,
},
Suffix {
length: u64,
},
}Expand description
One HTTP byte range. Bounded ranges use an exclusive end in Rust and are rendered with the inclusive end required by HTTP.
Variants
Implementations
Sourceimpl ObjectByteRange
impl ObjectByteRange
pub const fn bounded( start: u64, end_exclusive: u64, ) -> Result<Self, ObjectTransferError>
pub const fn from(start: u64) -> Self
pub const fn suffix(length: u64) -> Result<Self, ObjectTransferError>
pub fn to_http_value(self) -> String
pub const fn validate(self) -> Result<(), ObjectTransferError>