MemoryObjectStore

Struct MemoryObjectStore 

pub struct MemoryObjectStore { /* private fields */ }

Implementations

Source

impl MemoryObjectStore

pub async fn len(&self) -> usize

Number of objects currently retained by the deterministic memory adapter.

This is primarily useful for conformance tests and local diagnostics.

pub async fn is_empty(&self) -> bool