ObjectUploadSigner

Trait ObjectUploadSigner 

pub trait ObjectUploadSigner:
    Send
    + Sync
    + Debug {
    // Required method
    fn sign_upload<'life0, 'async_trait>(
        &'life0 self,
        request: SignObjectUpload,
    ) -> Pin<Box<dyn Future<Output = Result<PresignedObjectRequest, ObjectUploadError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Provider adapter that can bind an upload capability to exact bytes.

This is separate from ObjectAccessSigner so the compatibility-preserving PresignPutObject contract can remain available while managed uploads require an exact size and SHA-256 checksum.

Required Methods

fn sign_upload<'life0, 'async_trait>( &'life0 self, request: SignObjectUpload, ) -> Pin<Box<dyn Future<Output = Result<PresignedObjectRequest, ObjectUploadError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors